@@ -9,7 +9,13 @@ if (!is.R()) {
 }
 
 "CRS" <- function(projargs) {
+    if (missing(projargs)) projargs <- as.character(NA)
     if (nchar(projargs) == 0) projargs <- as.character(NA)
+    if (!is.na(projargs)) {
+        if (length(grep("^[ ]*\\+", projargs)) == 0)
+            stop(paste("PROJ4 argument-value pairs must begin with +:", 
+	        projargs))
+    }
     if (is.na(projargs)) uprojargs <- projargs
     else uprojargs <- paste(unique(unlist(strsplit(projargs, " "))), 
 	collapse=" ")
@@ -22,13 +28,14 @@ if (!is.R()) {
 #    if (length(grep("rgdal", search()) > 0) &&
 #      (sessionInfo()$otherPkgs$rgdal$Version > "0.4-2")) {
 # sessionInfo()/read.dcf() problem in loop 080307
-     if ("rgdal" %in% .packages()) {
+    if ("rgdal" %in% .packages()) {
 	if (!is.na(uprojargs)) {
-		res <- .Call("checkCRSArgs", uprojargs, 
-				PACKAGE="rgdal")
-	} else res <- list(TRUE, as.character(NA))
-	if (!res[[1]]) stop(res[[2]])
-	else uprojargs <- res[[2]]
+	    res <- checkCRSArgs(uprojargs)
+	    if (!res[[1]]) 
+	    	stop(res[[2]])
+            uprojargs <- res[[2]]
+	} else
+            uprojargs <- as.character(NA)
     }
     res <- new("CRS", projargs=uprojargs)
     res
@@ -43,3 +50,7 @@ if (!is.R()) {
 }
 
 setMethod("show", "CRS", function(object) print.CRS(object))
+
+identicalCRS = function(x,y) {
+	identical(CRS(proj4string(x)), CRS(proj4string(y)))
+}
